==> haskell-generic-lens-core-2.0.0.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-lens-core
version:              2.0.0.0
visibility:           public
id:                   generic-lens-core-2.0.0.0-KIFiLKUEV3B5vOD912muTq
key:                  generic-lens-core-2.0.0.0-KIFiLKUEV3B5vOD912muTq
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    This package is the shared internal logic of the
    @<https://hackage.haskell.org/package/generic-lens generic-lens>@
    and
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@
    libraries.

category:             Generics, Records, Lens
abi:                  d1975778cd17973471a032bb2b35e2ac
exposed:              True
exposed-modules:
    Data.GenericLens.Internal Data.Generics.Internal.Errors
    Data.Generics.Internal.Families
    Data.Generics.Internal.Families.Changing
    Data.Generics.Internal.Families.Collect
    Data.Generics.Internal.Families.Has Data.Generics.Internal.GenericN
    Data.Generics.Internal.Profunctor.Iso
    Data.Generics.Internal.Profunctor.Lens
    Data.Generics.Internal.Profunctor.Prism
    Data.Generics.Internal.VL.Traversal Data.Generics.Internal.Void
    Data.Generics.Internal.Wrapped
    Data.Generics.Product.Internal.Fields
    Data.Generics.Product.Internal.GLens
    Data.Generics.Product.Internal.HList
    Data.Generics.Product.Internal.Param
    Data.Generics.Product.Internal.Positions
    Data.Generics.Product.Internal.Subtype
    Data.Generics.Product.Internal.Typed
    Data.Generics.Product.Internal.Types
    Data.Generics.Sum.Internal.Constructors
    Data.Generics.Sum.Internal.Subtype Data.Generics.Sum.Internal.Typed

import-dirs:          /usr/lib/ghc-8.10.2/site-local/generic-lens-core-2.0.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/generic-lens-core-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/generic-lens-core-2.0.0.0

hs-libraries:         HSgeneric-lens-core-2.0.0.0-KIFiLKUEV3B5vOD912muTq
depends:
    base-4.14.1.0 indexed-profunctors-0.1-G2xyUs8t16g9eLVmVekckX
    text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens-core/html/generic-lens-core.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-lens-core-2.0.0.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-lens-core
version:              2.0.0.0
visibility:           public
id:                   generic-lens-core-2.0.0.0-6O7MpJjuK5DHTraWvws1zW
key:                  generic-lens-core-2.0.0.0-6O7MpJjuK5DHTraWvws1zW
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    This package is the shared internal logic of the
    @<https://hackage.haskell.org/package/generic-lens generic-lens>@
    and
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@
    libraries.

category:             Generics, Records, Lens
abi:                  1b5ad3a8d1775a2f8e488f7a5aed5f27
exposed:              True
exposed-modules:
    Data.GenericLens.Internal Data.Generics.Internal.Errors
    Data.Generics.Internal.Families
    Data.Generics.Internal.Families.Changing
    Data.Generics.Internal.Families.Collect
    Data.Generics.Internal.Families.Has Data.Generics.Internal.GenericN
    Data.Generics.Internal.Profunctor.Iso
    Data.Generics.Internal.Profunctor.Lens
    Data.Generics.Internal.Profunctor.Prism
    Data.Generics.Internal.VL.Traversal Data.Generics.Internal.Void
    Data.Generics.Internal.Wrapped
    Data.Generics.Product.Internal.Fields
    Data.Generics.Product.Internal.GLens
    Data.Generics.Product.Internal.HList
    Data.Generics.Product.Internal.Param
    Data.Generics.Product.Internal.Positions
    Data.Generics.Product.Internal.Subtype
    Data.Generics.Product.Internal.Typed
    Data.Generics.Product.Internal.Types
    Data.Generics.Sum.Internal.Constructors
    Data.Generics.Sum.Internal.Subtype Data.Generics.Sum.Internal.Typed

import-dirs:          /usr/lib/ghc-8.10.3/site-local/generic-lens-core-2.0.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/generic-lens-core-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/generic-lens-core-2.0.0.0

hs-libraries:         HSgeneric-lens-core-2.0.0.0-6O7MpJjuK5DHTraWvws1zW
depends:
    base-4.14.1.0 indexed-profunctors-0.1-G2xyUs8t16g9eLVmVekckX
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens-core/html/generic-lens-core.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
